Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1034)

Unified Diff: Source/core/html/canvas/WebGLExtension.h

Issue 24096029: Moved the majority of WebGL functionality into WebGLRenderingContextBase (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/html/canvas/WebGLExtension.h
diff --git a/Source/core/html/canvas/WebGLExtension.h b/Source/core/html/canvas/WebGLExtension.h
index 4028906fb04ad351e714a304e69cf9ed28e50e4f..2c9a786084ad163d078d2da1d5f0c5edf9bbb592 100644
--- a/Source/core/html/canvas/WebGLExtension.h
+++ b/Source/core/html/canvas/WebGLExtension.h
@@ -26,7 +26,7 @@
#ifndef WebGLExtension_h
#define WebGLExtension_h
-#include "core/html/canvas/WebGLRenderingContext.h"
+#include "core/html/canvas/WebGLRenderingContextBase.h"
#include "wtf/RefCounted.h"
namespace WebCore {
@@ -56,14 +56,14 @@ public:
WebGLLoseContextName,
};
- WebGLRenderingContext* context() { return m_context; }
+ WebGLRenderingContextBase* context() { return m_context; }
virtual ~WebGLExtension();
virtual ExtensionName getName() const = 0;
// Lose this extension. Passing true = force loss. Some extensions
// like WEBGL_lose_context are not normally lost when the context
// is lost but must be lost when destroying their WebGLRenderingContext.
virtual void lose(bool)
{
m_context = 0;
@@ -75,9 +75,9 @@ public:
}
protected:
- WebGLExtension(WebGLRenderingContext*);
+ WebGLExtension(WebGLRenderingContextBase*);
- WebGLRenderingContext* m_context;
+ WebGLRenderingContextBase* m_context;
};
} // namespace WebCore
@@ -56,14 +56,14 @@ public:
// Lose this extension. Passing true = force loss. Some extensions
// like WEBGL_lose_context are not normally lost when the context
- // is lost but must be lost when destroying their WebGLRenderingContext.
+ // is lost but must be lost when destroying their WebGLRenderingContextBase.
virtual void lose(bool)
{

Powered by Google App Engine
This is Rietveld 408576698